@@ -1,6 +1,6 @@
 package ShardedKV::Storage::MySQL;
 {
-  $ShardedKV::Storage::MySQL::VERSION = '0.10';
+  $ShardedKV::Storage::MySQL::VERSION = '0.11';
 }
 use Moose;
 # ABSTRACT: MySQL storage backend for ShardedKV
@@ -128,11 +128,16 @@ has '_number_of_params' => (
   builder => '_calc_no_params',
 );
 
+sub BUILD {
+  $_[0]->_number_of_params;
+};
+
 sub _calc_no_params {
   my $self = shift;
   return 1 + scalar(@{$self->value_col_names});
 }
 
+
 sub _make_get_query {
   my $self = shift;
   $self->_number_of_params; # prepopulate
@@ -277,7 +282,7 @@ ShardedKV::Storage::MySQL - MySQL storage backend for ShardedKV
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
